API
======

.. automodule:: sftpretty
   :members:


SFTPAttributes
--------------
See https://docs.paramiko.org/en/latest/api/sftp.html?highlight=sftpattributes#paramiko.sftp_attr.SFTPAttributes for details


SFTPFile
--------
See https://docs.paramiko.org/en/latest/api/sftp.html?highlight=paramiko.sftp_file.sftpfile#paramiko.sftp_file.SFTPFile for details


SecurityOptions
---------------
A simple object returned with available Security Options

See https://docs.paramiko.org/en/latest/api/transport.html?highlight=ciphers#paramiko.transport.SecurityOptions for details
